@@ -6,9 +6,9 @@ Type annotations for chime-sdk-identity service type definitions.
 Usage::
 
     ```python
-    from mypy_boto3_chime_sdk_identity.type_defs import AppInstanceAdminSummaryTypeDef
+    from mypy_boto3_chime_sdk_identity.type_defs import IdentityTypeDef
 
-    data: AppInstanceAdminSummaryTypeDef = {...}
+    data: IdentityTypeDef = {...}
     ```
 """
 import sys
@@ -29,87 +29,79 @@ else:
 
 
 __all__ = (
-    "AppInstanceAdminSummaryTypeDef",
-    "AppInstanceAdminTypeDef",
-    "AppInstanceRetentionSettingsTypeDef",
+    "IdentityTypeDef",
+    "ChannelRetentionSettingsTypeDef",
     "AppInstanceSummaryTypeDef",
     "AppInstanceTypeDef",
-    "AppInstanceUserEndpointSummaryTypeDef",
-    "AppInstanceUserEndpointTypeDef",
+    "EndpointStateTypeDef",
+    "EndpointAttributesTypeDef",
     "AppInstanceUserSummaryTypeDef",
     "AppInstanceUserTypeDef",
-    "ChannelRetentionSettingsTypeDef",
     "CreateAppInstanceAdminRequestRequestTypeDef",
-    "CreateAppInstanceAdminResponseTypeDef",
-    "CreateAppInstanceRequestRequestTypeDef",
-    "CreateAppInstanceResponseTypeDef",
-    "CreateAppInstanceUserRequestRequestTypeDef",
-    "CreateAppInstanceUserResponseTypeDef",
+    "ResponseMetadataTypeDef",
+    "TagTypeDef",
     "DeleteAppInstanceAdminRequestRequestTypeDef",
     "DeleteAppInstanceRequestRequestTypeDef",
     "DeleteAppInstanceUserRequestRequestTypeDef",
     "DeregisterAppInstanceUserEndpointRequestRequestTypeDef",
     "DescribeAppInstanceAdminRequestRequestTypeDef",
-    "DescribeAppInstanceAdminResponseTypeDef",
     "DescribeAppInstanceRequestRequestTypeDef",
-    "DescribeAppInstanceResponseTypeDef",
     "DescribeAppInstanceUserEndpointRequestRequestTypeDef",
-    "DescribeAppInstanceUserEndpointResponseTypeDef",
     "DescribeAppInstanceUserRequestRequestTypeDef",
-    "DescribeAppInstanceUserResponseTypeDef",
-    "EndpointAttributesTypeDef",
-    "EndpointStateTypeDef",
     "GetAppInstanceRetentionSettingsRequestRequestTypeDef",
-    "GetAppInstanceRetentionSettingsResponseTypeDef",
-    "IdentityTypeDef",
     "ListAppInstanceAdminsRequestRequestTypeDef",
-    "ListAppInstanceAdminsResponseTypeDef",
     "ListAppInstanceUserEndpointsRequestRequestTypeDef",
-    "ListAppInstanceUserEndpointsResponseTypeDef",
     "ListAppInstanceUsersRequestRequestTypeDef",
-    "ListAppInstanceUsersResponseTypeDef",
     "ListAppInstancesRequestRequestTypeDef",
-    "ListAppInstancesResponseTypeDef",
     "ListTagsForResourceRequestRequestTypeDef",
-    "ListTagsForResourceResponseTypeDef",
-    "PutAppInstanceRetentionSettingsRequestRequestTypeDef",
-    "PutAppInstanceRetentionSettingsResponseTypeDef",
-    "RegisterAppInstanceUserEndpointRequestRequestTypeDef",
-    "RegisterAppInstanceUserEndpointResponseTypeDef",
-    "ResponseMetadataTypeDef",
-    "TagResourceRequestRequestTypeDef",
-    "TagTypeDef",
     "UntagResourceRequestRequestTypeDef",
     "UpdateAppInstanceRequestRequestTypeDef",
-    "UpdateAppInstanceResponseTypeDef",
     "UpdateAppInstanceUserEndpointRequestRequestTypeDef",
-    "UpdateAppInstanceUserEndpointResponseTypeDef",
     "UpdateAppInstanceUserRequestRequestTypeDef",
-    "UpdateAppInstanceUserResponseTypeDef",
-)
-
-AppInstanceAdminSummaryTypeDef = TypedDict(
     "AppInstanceAdminSummaryTypeDef",
-    {
-        "Admin": "IdentityTypeDef",
-    },
-    total=False,
-)
-
-AppInstanceAdminTypeDef = TypedDict(
     "AppInstanceAdminTypeDef",
+    "AppInstanceRetentionSettingsTypeDef",
+    "AppInstanceUserEndpointSummaryTypeDef",
+    "AppInstanceUserEndpointTypeDef",
+    "RegisterAppInstanceUserEndpointRequestRequestTypeDef",
+    "CreateAppInstanceAdminResponseTypeDef",
+    "CreateAppInstanceResponseTypeDef",
+    "CreateAppInstanceUserResponseTypeDef",
+    "DescribeAppInstanceResponseTypeDef",
+    "DescribeAppInstanceUserResponseTypeDef",
+    "EmptyResponseMetadataTypeDef",
+    "ListAppInstanceUsersResponseTypeDef",
+    "ListAppInstancesResponseTypeDef",
+    "RegisterAppInstanceUserEndpointResponseTypeDef",
+    "UpdateAppInstanceResponseTypeDef",
+    "UpdateAppInstanceUserEndpointResponseTypeDef",
+    "UpdateAppInstanceUserResponseTypeDef",
+    "CreateAppInstanceRequestRequestTypeDef",
+    "CreateAppInstanceUserRequestRequestTypeDef",
+    "ListTagsForResourceResponseTypeDef",
+    "TagResourceRequestRequestTypeDef",
+    "ListAppInstanceAdminsResponseTypeDef",
+    "DescribeAppInstanceAdminResponseTypeDef",
+    "GetAppInstanceRetentionSettingsResponseTypeDef",
+    "PutAppInstanceRetentionSettingsRequestRequestTypeDef",
+    "PutAppInstanceRetentionSettingsResponseTypeDef",
+    "ListAppInstanceUserEndpointsResponseTypeDef",
+    "DescribeAppInstanceUserEndpointResponseTypeDef",
+)
+
+IdentityTypeDef = TypedDict(
+    "IdentityTypeDef",
     {
-        "Admin": "IdentityTypeDef",
-        "AppInstanceArn": str,
-        "CreatedTimestamp": datetime,
+        "Arn": str,
+        "Name": str,
     },
     total=False,
 )
 
-AppInstanceRetentionSettingsTypeDef = TypedDict(
-    "AppInstanceRetentionSettingsTypeDef",
+ChannelRetentionSettingsTypeDef = TypedDict(
+    "ChannelRetentionSettingsTypeDef",
     {
-        "ChannelRetentionSettings": "ChannelRetentionSettingsTypeDef",
+        "RetentionDays": int,
     },
     total=False,
 )
@@ -136,36 +128,46 @@ AppInstanceTypeDef = TypedDict(
     total=False,
 )
 
-AppInstanceUserEndpointSummaryTypeDef = TypedDict(
-    "AppInstanceUserEndpointSummaryTypeDef",
+_RequiredEndpointStateTypeDef = TypedDict(
+    "_RequiredEndpointStateTypeDef",
     {
-        "AppInstanceUserArn": str,
-        "EndpointId": str,
-        "Name": str,
-        "Type": AppInstanceUserEndpointTypeType,
-        "AllowMessages": AllowMessagesType,
-        "EndpointState": "EndpointStateTypeDef",
+        "Status": EndpointStatusType,
+    },
+)
+_OptionalEndpointStateTypeDef = TypedDict(
+    "_OptionalEndpointStateTypeDef",
+    {
+        "StatusReason": EndpointStatusReasonType,
     },
     total=False,
 )
 
-AppInstanceUserEndpointTypeDef = TypedDict(
-    "AppInstanceUserEndpointTypeDef",
+
+class EndpointStateTypeDef(_RequiredEndpointStateTypeDef, _OptionalEndpointStateTypeDef):
+    pass
+
+
+_RequiredEndpointAttributesTypeDef = TypedDict(
+    "_RequiredEndpointAttributesTypeDef",
     {
-        "AppInstanceUserArn": str,
-        "EndpointId": str,
-        "Name": str,
-        "Type": AppInstanceUserEndpointTypeType,
-        "ResourceArn": str,
-        "EndpointAttributes": "EndpointAttributesTypeDef",
-        "CreatedTimestamp": datetime,
-        "LastUpdatedTimestamp": datetime,
-        "AllowMessages": AllowMessagesType,
-        "EndpointState": "EndpointStateTypeDef",
+        "DeviceToken": str,
+    },
+)
+_OptionalEndpointAttributesTypeDef = TypedDict(
+    "_OptionalEndpointAttributesTypeDef",
+    {
+        "VoipDeviceToken": str,
     },
     total=False,
 )
 
+
+class EndpointAttributesTypeDef(
+    _RequiredEndpointAttributesTypeDef, _OptionalEndpointAttributesTypeDef
+):
+    pass
+
+
 AppInstanceUserSummaryTypeDef = TypedDict(
     "AppInstanceUserSummaryTypeDef",
     {
@@ -188,14 +190,6 @@ AppInstanceUserTypeDef = TypedDict(
     total=False,
 )
 
-ChannelRetentionSettingsTypeDef = TypedDict(
-    "ChannelRetentionSettingsTypeDef",
-    {
-        "RetentionDays": int,
-    },
-    total=False,
-)
-
 CreateAppInstanceAdminRequestRequestTypeDef = TypedDict(
     "CreateAppInstanceAdminRequestRequestTypeDef",
     {
@@ -204,77 +198,22 @@ CreateAppInstanceAdminRequestRequestTypeDef = TypedDict(
     },
 )
 
-CreateAppInstanceAdminResponseTypeDef = TypedDict(
-    "CreateAppInstanceAdminResponseTypeDef",
+ResponseMetadataTypeDef = TypedDict(
+    "ResponseMetadataTypeDef",
     {
-        "AppInstanceAdmin": "IdentityTypeDef",
-        "AppInstanceArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "RequestId": str,
+        "HostId": str,
+        "HTTPStatusCode": int,
+        "HTTPHeaders": Dict[str, str],
+        "RetryAttempts": int,
     },
 )
 
-_RequiredCreateAppInstanceRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAppInstanceRequestRequestTypeDef",
+TagTypeDef = TypedDict(
+    "TagTypeDef",
     {
-        "Name": str,
-        "ClientRequestToken": str,
-    },
-)
-_OptionalCreateAppInstanceRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAppInstanceRequestRequestTypeDef",
-    {
-        "Metadata": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateAppInstanceRequestRequestTypeDef(
-    _RequiredCreateAppInstanceRequestRequestTypeDef, _OptionalCreateAppInstanceRequestRequestTypeDef
-):
-    pass
-
-
-CreateAppInstanceResponseTypeDef = TypedDict(
-    "CreateAppInstanceResponseTypeDef",
-    {
-        "AppInstanceArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredCreateAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "_RequiredCreateAppInstanceUserRequestRequestTypeDef",
-    {
-        "AppInstanceArn": str,
-        "AppInstanceUserId": str,
-        "Name": str,
-        "ClientRequestToken": str,
-    },
-)
-_OptionalCreateAppInstanceUserRequestRequestTypeDef = TypedDict(
-    "_OptionalCreateAppInstanceUserRequestRequestTypeDef",
-    {
-        "Metadata": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-    total=False,
-)
-
-
-class CreateAppInstanceUserRequestRequestTypeDef(
-    _RequiredCreateAppInstanceUserRequestRequestTypeDef,
-    _OptionalCreateAppInstanceUserRequestRequestTypeDef,
-):
-    pass
-
-
-CreateAppInstanceUserResponseTypeDef = TypedDict(
-    "CreateAppInstanceUserResponseTypeDef",
-    {
-        "AppInstanceUserArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "Key": str,
+        "Value": str,
     },
 )
 
@@ -316,14 +255,6 @@ DescribeAppInstanceAdminRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeAppInstanceAdminResponseTypeDef = TypedDict(
-    "DescribeAppInstanceAdminResponseTypeDef",
-    {
-        "AppInstanceAdmin": "AppInstanceAdminTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeAppInstanceRequestRequestTypeDef = TypedDict(
     "DescribeAppInstanceRequestRequestTypeDef",
     {
@@ -331,14 +262,6 @@ DescribeAppInstanceRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeAppInstanceResponseTypeDef = TypedDict(
-    "DescribeAppInstanceResponseTypeDef",
-    {
-        "AppInstance": "AppInstanceTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
     "DescribeAppInstanceUserEndpointRequestRequestTypeDef",
     {
@@ -347,14 +270,6 @@ DescribeAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeAppInstanceUserEndpointResponseTypeDef = TypedDict(
-    "DescribeAppInstanceUserEndpointResponseTypeDef",
-    {
-        "AppInstanceUserEndpoint": "AppInstanceUserEndpointTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 DescribeAppInstanceUserRequestRequestTypeDef = TypedDict(
     "DescribeAppInstanceUserRequestRequestTypeDef",
     {
@@ -362,54 +277,6 @@ DescribeAppInstanceUserRequestRequestTypeDef = TypedDict(
     },
 )
 
-DescribeAppInstanceUserResponseTypeDef = TypedDict(
-    "DescribeAppInstanceUserResponseTypeDef",
-    {
-        "AppInstanceUser": "AppInstanceUserTypeDef",
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredEndpointAttributesTypeDef = TypedDict(
-    "_RequiredEndpointAttributesTypeDef",
-    {
-        "DeviceToken": str,
-    },
-)
-_OptionalEndpointAttributesTypeDef = TypedDict(
-    "_OptionalEndpointAttributesTypeDef",
-    {
-        "VoipDeviceToken": str,
-    },
-    total=False,
-)
-
-
-class EndpointAttributesTypeDef(
-    _RequiredEndpointAttributesTypeDef, _OptionalEndpointAttributesTypeDef
-):
-    pass
-
-
-_RequiredEndpointStateTypeDef = TypedDict(
-    "_RequiredEndpointStateTypeDef",
-    {
-        "Status": EndpointStatusType,
-    },
-)
-_OptionalEndpointStateTypeDef = TypedDict(
-    "_OptionalEndpointStateTypeDef",
-    {
-        "StatusReason": EndpointStatusReasonType,
-    },
-    total=False,
-)
-
-
-class EndpointStateTypeDef(_RequiredEndpointStateTypeDef, _OptionalEndpointStateTypeDef):
-    pass
-
-
 GetAppInstanceRetentionSettingsRequestRequestTypeDef = TypedDict(
     "GetAppInstanceRetentionSettingsRequestRequestTypeDef",
     {
@@ -417,24 +284,6 @@ GetAppInstanceRetentionSettingsRequestRequestTypeDef = TypedDict(
     },
 )
 
-GetAppInstanceRetentionSettingsResponseTypeDef = TypedDict(
-    "GetAppInstanceRetentionSettingsResponseTypeDef",
-    {
-        "AppInstanceRetentionSettings": "AppInstanceRetentionSettingsTypeDef",
-        "InitiateDeletionTimestamp": datetime,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-IdentityTypeDef = TypedDict(
-    "IdentityTypeDef",
-    {
-        "Arn": str,
-        "Name": str,
-    },
-    total=False,
-)
-
 _RequiredListAppInstanceAdminsRequestRequestTypeDef = TypedDict(
     "_RequiredListAppInstanceAdminsRequestRequestTypeDef",
     {
@@ -458,16 +307,6 @@ class ListAppInstanceAdminsRequestRequestTypeDef(
     pass
 
 
-ListAppInstanceAdminsResponseTypeDef = TypedDict(
-    "ListAppInstanceAdminsResponseTypeDef",
-    {
-        "AppInstanceArn": str,
-        "AppInstanceAdmins": List["AppInstanceAdminSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredListAppInstanceUserEndpointsRequestRequestTypeDef = TypedDict(
     "_RequiredListAppInstanceUserEndpointsRequestRequestTypeDef",
     {
@@ -491,15 +330,6 @@ class ListAppInstanceUserEndpointsRequestRequestTypeDef(
     pass
 
 
-ListAppInstanceUserEndpointsResponseTypeDef = TypedDict(
-    "ListAppInstanceUserEndpointsResponseTypeDef",
-    {
-        "AppInstanceUserEndpoints": List["AppInstanceUserEndpointSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredListAppInstanceUsersRequestRequestTypeDef = TypedDict(
     "_RequiredListAppInstanceUsersRequestRequestTypeDef",
     {
@@ -523,16 +353,6 @@ class ListAppInstanceUsersRequestRequestTypeDef(
     pass
 
 
-ListAppInstanceUsersResponseTypeDef = TypedDict(
-    "ListAppInstanceUsersResponseTypeDef",
-    {
-        "AppInstanceArn": str,
-        "AppInstanceUsers": List["AppInstanceUserSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListAppInstancesRequestRequestTypeDef = TypedDict(
     "ListAppInstancesRequestRequestTypeDef",
     {
@@ -542,15 +362,6 @@ ListAppInstancesRequestRequestTypeDef = TypedDict(
     total=False,
 )
 
-ListAppInstancesResponseTypeDef = TypedDict(
-    "ListAppInstancesResponseTypeDef",
-    {
-        "AppInstances": List["AppInstanceSummaryTypeDef"],
-        "NextToken": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 ListTagsForResourceRequestRequestTypeDef = TypedDict(
     "ListTagsForResourceRequestRequestTypeDef",
     {
@@ -558,94 +369,6 @@ ListTagsForResourceRequestRequestTypeDef = TypedDict(
     },
 )
 
-ListTagsForResourceResponseTypeDef = TypedDict(
-    "ListTagsForResourceResponseTypeDef",
-    {
-        "Tags": List["TagTypeDef"],
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-PutAppInstanceRetentionSettingsRequestRequestTypeDef = TypedDict(
-    "PutAppInstanceRetentionSettingsRequestRequestTypeDef",
-    {
-        "AppInstanceArn": str,
-        "AppInstanceRetentionSettings": "AppInstanceRetentionSettingsTypeDef",
-    },
-)
-
-PutAppInstanceRetentionSettingsResponseTypeDef = TypedDict(
-    "PutAppInstanceRetentionSettingsResponseTypeDef",
-    {
-        "AppInstanceRetentionSettings": "AppInstanceRetentionSettingsTypeDef",
-        "InitiateDeletionTimestamp": datetime,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-_RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
-    "_RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef",
-    {
-        "AppInstanceUserArn": str,
-        "Type": AppInstanceUserEndpointTypeType,
-        "ResourceArn": str,
-        "EndpointAttributes": "EndpointAttributesTypeDef",
-        "ClientRequestToken": str,
-    },
-)
-_OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
-    "_OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef",
-    {
-        "Name": str,
-        "AllowMessages": AllowMessagesType,
-    },
-    total=False,
-)
-
-
-class RegisterAppInstanceUserEndpointRequestRequestTypeDef(
-    _RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef,
-    _OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef,
-):
-    pass
-
-
-RegisterAppInstanceUserEndpointResponseTypeDef = TypedDict(
-    "RegisterAppInstanceUserEndpointResponseTypeDef",
-    {
-        "AppInstanceUserArn": str,
-        "EndpointId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
-ResponseMetadataTypeDef = TypedDict(
-    "ResponseMetadataTypeDef",
-    {
-        "RequestId": str,
-        "HostId": str,
-        "HTTPStatusCode": int,
-        "HTTPHeaders": Dict[str, str],
-        "RetryAttempts": int,
-    },
-)
-
-TagResourceRequestRequestTypeDef = TypedDict(
-    "TagResourceRequestRequestTypeDef",
-    {
-        "ResourceARN": str,
-        "Tags": Sequence["TagTypeDef"],
-    },
-)
-
-TagTypeDef = TypedDict(
-    "TagTypeDef",
-    {
-        "Key": str,
-        "Value": str,
-    },
-)
-
 UntagResourceRequestRequestTypeDef = TypedDict(
     "UntagResourceRequestRequestTypeDef",
     {
@@ -663,14 +386,6 @@ UpdateAppInstanceRequestRequestTypeDef = TypedDict(
     },
 )
 
-UpdateAppInstanceResponseTypeDef = TypedDict(
-    "UpdateAppInstanceResponseTypeDef",
-    {
-        "AppInstanceArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 _RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
     "_RequiredUpdateAppInstanceUserEndpointRequestRequestTypeDef",
     {
@@ -695,15 +410,6 @@ class UpdateAppInstanceUserEndpointRequestRequestTypeDef(
     pass
 
 
-UpdateAppInstanceUserEndpointResponseTypeDef = TypedDict(
-    "UpdateAppInstanceUserEndpointResponseTypeDef",
-    {
-        "AppInstanceUserArn": str,
-        "EndpointId": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
-    },
-)
-
 UpdateAppInstanceUserRequestRequestTypeDef = TypedDict(
     "UpdateAppInstanceUserRequestRequestTypeDef",
     {
@@ -713,10 +419,312 @@ UpdateAppInstanceUserRequestRequestTypeDef = TypedDict(
     },
 )
 
+AppInstanceAdminSummaryTypeDef = TypedDict(
+    "AppInstanceAdminSummaryTypeDef",
+    {
+        "Admin": IdentityTypeDef,
+    },
+    total=False,
+)
+
+AppInstanceAdminTypeDef = TypedDict(
+    "AppInstanceAdminTypeDef",
+    {
+        "Admin": IdentityTypeDef,
+        "AppInstanceArn": str,
+        "CreatedTimestamp": datetime,
+    },
+    total=False,
+)
+
+AppInstanceRetentionSettingsTypeDef = TypedDict(
+    "AppInstanceRetentionSettingsTypeDef",
+    {
+        "ChannelRetentionSettings": ChannelRetentionSettingsTypeDef,
+    },
+    total=False,
+)
+
+AppInstanceUserEndpointSummaryTypeDef = TypedDict(
+    "AppInstanceUserEndpointSummaryTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+        "Name": str,
+        "Type": AppInstanceUserEndpointTypeType,
+        "AllowMessages": AllowMessagesType,
+        "EndpointState": EndpointStateTypeDef,
+    },
+    total=False,
+)
+
+AppInstanceUserEndpointTypeDef = TypedDict(
+    "AppInstanceUserEndpointTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+        "Name": str,
+        "Type": AppInstanceUserEndpointTypeType,
+        "ResourceArn": str,
+        "EndpointAttributes": EndpointAttributesTypeDef,
+        "CreatedTimestamp": datetime,
+        "LastUpdatedTimestamp": datetime,
+        "AllowMessages": AllowMessagesType,
+        "EndpointState": EndpointStateTypeDef,
+    },
+    total=False,
+)
+
+_RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "_RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "Type": AppInstanceUserEndpointTypeType,
+        "ResourceArn": str,
+        "EndpointAttributes": EndpointAttributesTypeDef,
+        "ClientRequestToken": str,
+    },
+)
+_OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef = TypedDict(
+    "_OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef",
+    {
+        "Name": str,
+        "AllowMessages": AllowMessagesType,
+    },
+    total=False,
+)
+
+
+class RegisterAppInstanceUserEndpointRequestRequestTypeDef(
+    _RequiredRegisterAppInstanceUserEndpointRequestRequestTypeDef,
+    _OptionalRegisterAppInstanceUserEndpointRequestRequestTypeDef,
+):
+    pass
+
+
+CreateAppInstanceAdminResponseTypeDef = TypedDict(
+    "CreateAppInstanceAdminResponseTypeDef",
+    {
+        "AppInstanceAdmin": IdentityTypeDef,
+        "AppInstanceArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateAppInstanceResponseTypeDef = TypedDict(
+    "CreateAppInstanceResponseTypeDef",
+    {
+        "AppInstanceArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+CreateAppInstanceUserResponseTypeDef = TypedDict(
+    "CreateAppInstanceUserResponseTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeAppInstanceResponseTypeDef = TypedDict(
+    "DescribeAppInstanceResponseTypeDef",
+    {
+        "AppInstance": AppInstanceTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeAppInstanceUserResponseTypeDef = TypedDict(
+    "DescribeAppInstanceUserResponseTypeDef",
+    {
+        "AppInstanceUser": AppInstanceUserTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+EmptyResponseMetadataTypeDef = TypedDict(
+    "EmptyResponseMetadataTypeDef",
+    {
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListAppInstanceUsersResponseTypeDef = TypedDict(
+    "ListAppInstanceUsersResponseTypeDef",
+    {
+        "AppInstanceArn": str,
+        "AppInstanceUsers": List[AppInstanceUserSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListAppInstancesResponseTypeDef = TypedDict(
+    "ListAppInstancesResponseTypeDef",
+    {
+        "AppInstances": List[AppInstanceSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+RegisterAppInstanceUserEndpointResponseTypeDef = TypedDict(
+    "RegisterAppInstanceUserEndpointResponseTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateAppInstanceResponseTypeDef = TypedDict(
+    "UpdateAppInstanceResponseTypeDef",
+    {
+        "AppInstanceArn": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+UpdateAppInstanceUserEndpointResponseTypeDef = TypedDict(
+    "UpdateAppInstanceUserEndpointResponseTypeDef",
+    {
+        "AppInstanceUserArn": str,
+        "EndpointId": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
 UpdateAppInstanceUserResponseTypeDef = TypedDict(
     "UpdateAppInstanceUserResponseTypeDef",
     {
         "AppInstanceUserArn": str,
-        "ResponseMetadata": "ResponseMetadataTypeDef",
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+_RequiredCreateAppInstanceRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAppInstanceRequestRequestTypeDef",
+    {
+        "Name": str,
+        "ClientRequestToken": str,
+    },
+)
+_OptionalCreateAppInstanceRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAppInstanceRequestRequestTypeDef",
+    {
+        "Metadata": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateAppInstanceRequestRequestTypeDef(
+    _RequiredCreateAppInstanceRequestRequestTypeDef, _OptionalCreateAppInstanceRequestRequestTypeDef
+):
+    pass
+
+
+_RequiredCreateAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "_RequiredCreateAppInstanceUserRequestRequestTypeDef",
+    {
+        "AppInstanceArn": str,
+        "AppInstanceUserId": str,
+        "Name": str,
+        "ClientRequestToken": str,
+    },
+)
+_OptionalCreateAppInstanceUserRequestRequestTypeDef = TypedDict(
+    "_OptionalCreateAppInstanceUserRequestRequestTypeDef",
+    {
+        "Metadata": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+    total=False,
+)
+
+
+class CreateAppInstanceUserRequestRequestTypeDef(
+    _RequiredCreateAppInstanceUserRequestRequestTypeDef,
+    _OptionalCreateAppInstanceUserRequestRequestTypeDef,
+):
+    pass
+
+
+ListTagsForResourceResponseTypeDef = TypedDict(
+    "ListTagsForResourceResponseTypeDef",
+    {
+        "Tags": List[TagTypeDef],
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+TagResourceRequestRequestTypeDef = TypedDict(
+    "TagResourceRequestRequestTypeDef",
+    {
+        "ResourceARN": str,
+        "Tags": Sequence[TagTypeDef],
+    },
+)
+
+ListAppInstanceAdminsResponseTypeDef = TypedDict(
+    "ListAppInstanceAdminsResponseTypeDef",
+    {
+        "AppInstanceArn": str,
+        "AppInstanceAdmins": List[AppInstanceAdminSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeAppInstanceAdminResponseTypeDef = TypedDict(
+    "DescribeAppInstanceAdminResponseTypeDef",
+    {
+        "AppInstanceAdmin": AppInstanceAdminTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+GetAppInstanceRetentionSettingsResponseTypeDef = TypedDict(
+    "GetAppInstanceRetentionSettingsResponseTypeDef",
+    {
+        "AppInstanceRetentionSettings": AppInstanceRetentionSettingsTypeDef,
+        "InitiateDeletionTimestamp": datetime,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+PutAppInstanceRetentionSettingsRequestRequestTypeDef = TypedDict(
+    "PutAppInstanceRetentionSettingsRequestRequestTypeDef",
+    {
+        "AppInstanceArn": str,
+        "AppInstanceRetentionSettings": AppInstanceRetentionSettingsTypeDef,
+    },
+)
+
+PutAppInstanceRetentionSettingsResponseTypeDef = TypedDict(
+    "PutAppInstanceRetentionSettingsResponseTypeDef",
+    {
+        "AppInstanceRetentionSettings": AppInstanceRetentionSettingsTypeDef,
+        "InitiateDeletionTimestamp": datetime,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+ListAppInstanceUserEndpointsResponseTypeDef = TypedDict(
+    "ListAppInstanceUserEndpointsResponseTypeDef",
+    {
+        "AppInstanceUserEndpoints": List[AppInstanceUserEndpointSummaryTypeDef],
+        "NextToken": str,
+        "ResponseMetadata": ResponseMetadataTypeDef,
+    },
+)
+
+DescribeAppInstanceUserEndpointResponseTypeDef = TypedDict(
+    "DescribeAppInstanceUserEndpointResponseTypeDef",
+    {
+        "AppInstanceUserEndpoint": AppInstanceUserEndpointTypeDef,
+        "ResponseMetadata": ResponseMetadataTypeDef,
     },
 )
